==> fop2-2.24-debian-x86_64.tgz: fop2/html/js/lang_pt_BR.js <==
// Translated by Carlos Cesario

lang['incoming_call']      = 'Recepção de chamada';
lang['connecting_server']  = 'Ligação ao servidor, tentativa número ';

lang['from_queue']         = "Da fila:";
lang['number']             = "Número:";
lang['name']               = "Nome:";

lang['dial']               = 'Chamar';
lang['transfer_vmail']     = 'Transferir para Caixa de Correio Electrónico';
lang['attendant_transfer'] = 'Transferir';
lang['transfer_external']  = 'Transferir para o celular';
lang['spy']                = 'Ouvir';
lang['whisper']            = 'Ouvir e Sussurrar';
lang['pickup']             = "Captura de Chamada";
lang['hangup']             = 'Desligar';
lang['filter']             = 'Filtrar';

lang['enter_sec_code']     = 'Detalhes de autenticação';
lang['exten']              = 'Extensão:';
lang['password']           = 'Senha:';

lang['confirm_hangup']     = 'Confirmar interrupção de chamada';
lang['areyousure']         = 'Tem a certeza?';

lang['yes']                = 'Sim';
lang['no']                 = 'Não';

lang['paused']             = 'Parado';
lang['set_information']    = 'Definir Informação';
lang['member_of']          = 'Membro de ';
lang['not_available']      = 'O sistema não está disponível no momento';
lang['not_connect']        = 'Não foi possível estabelecer ligação com o servidor';
lang['one_moment']         = 'Um momento por favor';
lang['no_results']         = 'Não foram encontrados resultados';

lang['toggle_lock']        = 'Bloquear/Desbloquear Conferência';
lang['toggle_muteall']     = 'Silenciar/Activar todos os utilizadores';
lang['available']          = 'Disponível';
lang['phonebook']          = 'Agenda Telefónica';
lang['toggle_mute']        = 'Alternar Silêncio';
lang['kick']               = 'Expulsar utilizador';
lang['record']             = 'Gravação de chamada';
lang['presence_noti']      = 'Notificação de presença';

lang['queues']             = 'Filas';
lang['extensions']         = 'Ramais';
lang['trunks']             = 'Troncais';
lang['conferences']        = 'Conferências';
lang['other']              = 'Outro';
lang['enter_state']        = 'Introduzir Valor';
lang['parkingslots']       = 'Lugares do Parque';
lang['ringgroups']         = 'Grupos de chamadas';

lang['enter_reg_code']     = 'Introduza o código de Registo:';
lang['reg_code']           = 'Código de Registo:';
lang['reg_name']           = 'Nome de Registo:';

lang['remove_member']      = 'Remover Membro';
lang['remove_member_from'] = 'Remover de ';
lang['pause_member']       = 'Parar Membro';
lang['unpause_member']     = 'Activar Membro';
lang['add_member']         = 'Adicionar a';
lang['pickup_call']        = 'Capturar chamada';
lang['email_user']         = 'Enviar email';
lang['send_sms']           = 'Enviar SMS';
lang['message']            = 'Mensagem:';
lang['sending']            = 'Envio...';
lang['noResponse']         = 'Sem resposta.';

lang['chat']               = 'Conversar';
lang['notlogged']          = 'O utilizador não registrado. Guardando nota.';
lang['me']                 = 'Eu';
lang['clearchat']          = 'Limpar janela de Conversação';
lang['note']               = 'Nota';
lang['toggle_sound']       = 'Alternar Som';
lang['says']               = 'diz';

lang['agents']             = 'Agentes: %d';
lang['calls']              = 'Chamadas em espera: %d';
lang['call_connected']     = 'Chamada com';
lang['changeDisplayType']  = 'Alterar tipo de apresentação';

lang['voicemail']          = 'Correio de voz';
lang['vmail_new']          = 'Novo';
lang['vmail_old']          = 'Antigo';
lang['vmail_work']         = 'Trabalho';
lang['vmail_family']       = 'Família';
lang['vmail_friends']      = 'Amigos';
lang['vmail_number']       = 'N.º';
lang['vmail_date']         = 'Data';
lang['vmail_callerid']     = 'CallerID';
lang['vmail_duration']     = 'Duração';

lang['preferences']        = 'Preferências';
lang['summary']            = 'Sumário';
lang['detailed']           = 'Detalhe';

lang['inactive_line']      = 'Linha %d inativa';
lang['inuse']              = '%d linhas em uso';

lang['vmail_count']        = 'Novo %d, Antigo %d';
lang['logout']             = 'Sair';

lang['NOTONLINE']          = 'Usuário offline';
lang['NOWONLINE']          = 'O usuário está conectado';

lang['prefSounds']         = 'Sons';
lang['prefDisplay']        = 'Apresentar';

lang['labelSoundChat']     = 'Sons da Conversa ';
lang['labelSoundQueue']    = 'Sons da Fila';
lang['labelSoundRing']     = 'Sons do toque';

lang['labelDisplayQueue']          = 'Vista da Fila por defeito:';
lang['labelDisplayDynamicLine']    = 'Mostrar linha dinâmica:';
lang['labelDisplayNotifyDuration'] = 'Notificar Duração:';
lang['labelDisplayLanguage']       = 'Linguagem:';


// Internationalization strings DATE
dateFormat.i18n = {
	dayNames: [
        "Dom","Seg","Ter","Qua","Qui","Sex","Sab",
        "Domingo", "Segunda-feira", "Terça-feira", "Quarta-feira", "Quinta-feira", "Sexta-feira", "Sabado"
	],
	monthNames: [
        "Jan"," Fev"," Mar"," Abr"," Mai"," Jun"," Jul"," Ago"," Set"," Out"," Nov"," Dez",
        "Janeiro","Fevereiro","Março","Abril","Maio","Junho","Julho","Agosto","Setembro","Outubro","Novembro","Dezembro"
	]
};

==> fop2-2.29.03-debian-x86_64.tgz: fop2/html/js/lang_pt_BR.js <==
// Translated by Carlos Cesario
// Updates by mowster

lang['incoming_call']      = 'Recepção de chamada';
lang['connecting_server']  = 'Ligação ao servidor, tentativa número ';

lang['from_queue']         = 'Da fila:';
lang['number']             = 'Número:';
lang['name']               = 'Nome:';

lang['dial']               = 'Ligar';
lang['transfer_vmail']     = 'Transferir para Correio Electrónico';
lang['attendant_transfer'] = 'Transferir';
lang['blind_transfer']     = 'Transferência cega';
lang['transfer_external']  = 'Transferir para o telemóvel';
lang['spy']                = 'Ouvir';
lang['whisper']            = 'Ouvir e Sussurrar';
lang['pickup']             = 'Captura de Chamada';
lang['hangup']             = 'Desligar';
lang['filter']             = 'Filtrar';

lang['enter_sec_code']     = 'Detalhes de autenticação';
lang['exten']              = 'Extensão:';
lang['password']           = 'Senha:';

lang['confirm_hangup']     = 'Confirmar interrupção de chamada';
lang['areyousure']         = 'Tem a certeza?';
lang['yes']                = 'Sim';
lang['no']                 = 'Não';
lang['cancel']             = 'Cancelar';
lang['accept']             = 'Aceitar';

lang['paused']             = 'Pausado';
lang['set_information']    = 'Definir Informação';
lang['set_penalty']        = 'Pena';
lang['member_of']          = 'Membro de ';
lang['not_available']      = 'O sistema não está disponível no momento';
lang['not_connect']        = 'Não foi possível estabelecer ligação com o servidor';
lang['one_moment']         = 'Um momento por favor';
lang['no_results']         = 'Não foram encontrados resultados';

lang['toggle_lock']        = 'Bloquear/Desbloquear Conferência';
lang['toggle_muteall']     = 'Silenciar/Activar todos os utilizadores';
lang['phonebook']          = 'Agenda Telefónica';
lang['toggle_mute']        = 'Alternar Silêncio';
lang['kick']               = 'Expulsar utilizador';
lang['record']             = 'Gravação de chamada';
lang['presence_noti']      = 'Notificação de presença';

lang['queues']             = 'Filas';
lang['extensions']         = 'Ramais';
lang['trunks']             = 'Troncais';
lang['conferences']        = 'Conferências';
lang['enter_state']        = 'Introduzir Valor';
lang['parkingslots']       = 'Lugares do Parque';
lang['ringgroups']         = 'Grupos de chamadas';

lang['available']          = 'Disponível';
lang['other']              = 'Outro';
lang['Do not Disturb']     = 'Não perturbar';
lang['Out to lunch']       = 'Refeição';
lang['Break']              = 'Intervalo';
lang['Meeting']            = 'Reunião';

lang['enter_reg_code']     = 'Introduza o código de Registo:';
lang['reg_code']           = 'Código de Registo:';
lang['reg_name']           = 'Nome de Registo:';

lang['remove_member']      = 'Remover Membro';
lang['remove_member_from'] = 'Remover de ';
lang['pause_member']       = 'Parar Membro';
lang['unpause_member']     = 'Activar Membro';
lang['add_member']         = 'Adicionar a';
lang['pickup_call']        = 'Capturar chamada';
lang['email_user']         = 'Enviar email';
lang['send_sms']           = 'Enviar SMS';
lang['message']            = 'Mensagem:';
lang['sending']            = 'Envio...';
lang['noResponse']         = 'Sem resposta.';
lang['calls_taken']        = 'Chamadas atendidas:';
lang['penalty']            = 'Pena:';

lang['chat']               = 'Conversar';
lang['notlogged']          = 'O utilizador não registrado. Guardando nota.';
lang['me']                 = 'Eu';
lang['clearchat']          = 'Limpar janela de Conversação';
lang['note']               = 'Nota';
lang['toggle_sound']       = 'Alternar Som';
lang['says']               = 'diz';

lang['agents']             = 'Agentes: %d';
lang['calls']              = 'Chamadas em espera: %d';
lang['call_connected']     = 'Chamada com';
lang['changeDisplayType']  = 'Alterar tipo de apresentação';

lang['voicemail']          = 'Correio de voz';
lang['vmail_new']          = 'Novo';
lang['vmail_old']          = 'Antigo';
lang['vmail_work']         = 'Trabalho';
lang['vmail_family']       = 'Família';
lang['vmail_friends']      = 'Amigos';
lang['vmail_number']       = 'N.º';
lang['vmail_date']         = 'Data';
lang['vmail_callerid']     = 'CallerID';
lang['vmail_duration']     = 'Duração';
lang['play']               = 'Reproduzir';
lang['download']           = 'Baixar';

lang['preferences']        = 'Preferências';
lang['summary']            = 'Sumário';
lang['detailed']           = 'Detalhe';

lang['inactive_line']      = 'Linha %d inativa';
lang['inuse']              = '%d linhas em uso';

lang['vmail_count']        = 'Novo %d, Antigo %d';
lang['logout']             = 'Sair';

lang['NOTONLINE']          = 'Usuário offline';
lang['NOWONLINE']          = 'O usuário está conectado';

lang['prefSounds']         = 'Sons';
lang['prefDisplay']        = 'Apresentar';
lang['prefPopup']          = 'Popup';
lang['prefPhone']          = 'Telefone';

lang['labelSoundChat']     = 'Sons da Conversa ';
lang['labelSoundQueue']    = 'Sons da Fila';
lang['labelSoundRing']     = 'Sons do toque';

lang['labelDisplayQueue']          = 'Vista da Fila por defeito';
lang['labelDisplayDynamicLine']    = 'Mostrar linha dinâmica';
lang['labelDisplayNotifyDuration'] = 'Notificar Duração';
lang['labelDisplayLanguage']       = 'Linguagem';
lang['labelAutoPopup']             = 'Auto Popup';
lang['labelAutoAnswer']            = 'Atendimento Automático';

lang['close']                      = 'Fechar';
lang['recordings']                 = 'Gravações';
lang['cdrrecords']                 = 'Historico De Chamadas';

// Internationalization strings DATE
dateFormat.i18n = {
	dayNames: [
        'Dom','Seg','Ter','Qua','Qui','Sex','Sab',
        'Domingo', 'Segunda-feira', 'Terça-feira', 'Quarta-feira', 'Quinta-feira', 'Sexta-feira', 'Sabado'
	],
	monthNames: [
        'Jan',' Fev',' Mar',' Abr',' Mai',' Jun',' Jul',' Ago',' Set',' Out',' Nov',' Dez',
        'Janeiro','Fevereiro','Março','Abril','Maio','Junho','Julho','Agosto','Setembro','Outubro','Novembro','Dezembro'
	]
};
